@@ -34,35 +34,13 @@ And much, much more. Everything has its own documentation so check it out.
     
 """
 from pythonix.internals.res import (
-    and_res,
-    and_then,
-    err,
-    flatten,
-    is_err,
-    is_err_and,
-    is_ok,
-    is_ok_and,
-    map,
-    map_err,
-    map_or,
-    map_or_else,
-    null_safe,
-    ok,
-    or_else,
-    safe,
-    map_err,
-    unwrap,
-    some,
     Res,
-    Opt,
     Nil,
-    or_res,
-    unwrap_err,
-    unwrap_or,
-    unwrap_or_else,
-    Ok,
-    Err,
+    UnwrapError,
+    ExpectError,
+    Nil,
     null_and_error_safe,
-    q,
-    qe,
+    combine_errors,
+    safe,
+    null_safe,
 )
